<?php

namespace App\Http\Controllers\Cms;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;

class CartController extends Controller
{
    public function cart_list()
    {
        $cart_items = \Cart::getContent();
        
        return view('frontend.shop.cart', compact('cart_items'));
    }


    public function add_to_cart(Request $request)
    {
        \Cart::add([
            'id' => $request->id,
            'name' => $request->name,
            'price' => $request->price,
            'quantity' => $request->quantity,
            'attributes' => array(
                'image' => $request->image,
            )
        ]);

        session()->flash('success', 'Product is Added to Cart Successfully !');
        return redirect()->back();

    }

    public function update_cart(Request $request)
    {
        \Cart::update(
            $request->id,
            [
                'quantity' => [
                    'relative' => false,
                    'value' => $request->quantity
                ],
            ]
        );

        session()->flash('info', 'Item Cart Updated Successfully !');

        return redirect()->back();
    }

    public function remove_cart(Request $request)
    {
        \Cart::remove($request->id);

        session()->flash('error', 'Item Cart Removed Successfully !');

        return redirect()->back();
    }

    public function clear_all_cart()
    {
        \Cart::clear();

        session()->flash('error', 'All Items Cart Cleared Successfully !');

        return redirect()->route('shop.cart.list');
    }

    public function shop_checkout()
    {
        if(\Cart::isEmpty()) {
            session()->flash('error', 'Your cart is empty ! Try again later.');
            return redirect()->route('shop.cart.list');
        } else {
            $cart_items = \Cart::getContent();
            
            return view('frontend.shop.checkout', compact('cart_items'));
        }
    }

    public function make_payment(Request $request)
    {
        $this->validate($request, [
            'bill_first_name' => 'required',
            'bill_last_name'  => 'required',
            'bill_company'    => 'required',
            'bill_address'    => 'required',
            'bill_postcode'   => 'required',
            'bill_city'       => 'required',
            'bill_email'      => 'required',
            'bill_phone'      => 'required',
            
            'del_first_name'  => 'required',
            'del_last_name'   => 'required',
            'del_company'     => 'required',
            'del_address'     => 'required',
            'del_postcode'    => 'required',
            'del_city'        => 'required',
            'del_email'       => 'required',
            'del_phone'       => 'required',
        ]);


        if(\Cart::isEmpty()) {
            session()->flash('error', 'Your cart is empty ! Try again later.');
            return redirect()->route('shop.cart.list');
        } else {
            $cart_items = \Cart::getContent();
            
            return view('frontend.shop.make-payment', compact('cart_items'));
        }
    }
}

