<?php

namespace App\Http\Controllers\Cms;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;

use App\Models\Service;
use App\Models\Contact;
use App\Models\Project;
use App\Models\Post;
use App\Models\Category;
use App\Models\Tag;
use App\Models\Product;
use App\Models\ProductCategory;
use App\Models\AppSettings;
use App\Models\Industry;

use Carbon\Carbon;
use DB;
use Session;

class FrontendController extends Controller
{

    public function home()
    {
        $img_services = Service::where('type', 'Security Services')->orderBy('created_at')->get();
        $settings = AppSettings::findOrFail(1);
        $all_services = Service::where('type', 'Security Services')->orderBy('created_at')->get();
        return view('frontend.index', compact( 'settings', 'all_services', 'img_services'));
    }
    
    public function get_section()
    { 
        $img_services = Service::where('type', 'Security Services')->orderBy('created_at')->get();
        $settings = AppSettings::findOrFail(1);

        return view('frontend.homesections', compact('img_services', 'settings'));
    }

    public function about()
    {
        return view('frontend.about');
    }

    public function security_services()
    {
        $all_services = Service::where('type', 'Security Services')->orderBy('created_at')->get();
        return view('frontend.services.security-services', compact('all_services'));
    }

    public function electrical_services()
    {
        $all_services = Service::where('type', 'Electrical Services')->orderBy('created_at')->get();
        return view('frontend.services.electrical-services', compact('all_services'));
    }

    public function air_conditioning()
    {
        $all_services = Service::where('type', '24/7 Site Cam')->orderBy('created_at')->get();
        return view('frontend.services.air-conditioning', compact('all_services'));
    }

    public function security_service_details($slug)
    {
        if ($slug == '24-7-alarm-monitoring') {
            $title = '24/7 Alarm monitoring';
        }elseif ($slug == '24-7-onsite-solar-cctv-monitoring') {
            $title = '24/7 Onsite Solar CCTV Monitoring';
        } else {
            $title = ucwords(str_replace('-', ' ', $slug));
        }
        
        $service = Service::where('name', $title)->first();

        if($service) {
            $all_solutions = json_decode($service->solutions);
        } else {
            abort(404);
        }

        // $count = count($all_solutions);
        // $divide = intval($count / 2);
        // $rest = $count - $divide;

        // $output_two = array_slice($all_solutions, 0, $divide);
        // $output_one = array_slice($all_solutions, $divide, $rest);

        return view('frontend.services.security-service-details', compact('service', 'all_solutions'));
    }

    public function electrical_service_details($slug)
    {
        if ($slug == '24-7-emergency-&-maintenance') {
            $title = '24/7 Emergency & Maintenance';
        } else {
            $title = ucwords(str_replace('-', ' ', $slug));
        }
            
        $service = Service::where('name', $title)->first();

        if($service) {
            $all_solutions = json_decode($service->solutions);
        } else {
            abort(404);
        }

        // $count = count($all_solutions);
        // $divide = intval($count / 2);
        // $rest = $count - $divide;

        // $output_two = array_slice($all_solutions, 0, $divide);
        // $output_one = array_slice($all_solutions, $divide, $rest);

        return view('frontend.services.electrical-service-details', compact('service', 'all_solutions'));
    }
    public function air_conditioning_details($slug)
    {
        $title = ucwords(str_replace('-', ' ', $slug));            
        $service = Service::where('name', $title)->first();

        if($service) {
            $all_solutions = json_decode($service->solutions);
        } else {
            abort(404);
        }

        return view('frontend.services.airc-service-details', compact('service', 'all_solutions'));
    }

    public function projects()
    {
        return view('frontend.coming-soon');
        // $all_projects = Project::orderBy('created_at', 'desc')->get();

        // return view('frontend.projects.all-projects', compact('all_projects'));

    }

    public function project_details($slug)
    {

        $title = ucwords(str_replace('-', ' ', $slug));
        $project = Project::where('title', $title)->first();

        if($project) {
            $images = (array) json_decode($project->images, true);
        } else {
            abort(404);
        }

        return view('frontend.projects.project-details', compact('project', 'images'));

    }
    
    public function industries()
    {
        
        $all_industries = Industry::orderBy('created_at', 'desc')->get();

        return view('frontend.industries.all-industries', compact('all_industries'));

    }

    public function industry_details($slug)
    {

        $industry = Industry::where('slug', $slug)->first();
        $includes = json_decode($industry->includes, true);

        //rsort($includes);
        
        return view('frontend.industries.industry-details', compact('industry', 'includes'));

    }

    public function blogs()
    {
        $all_blogs = Post::orderBy('created_at', 'desc')->paginate(6);

        return view('frontend.blogs.all-blogs', compact('all_blogs'));

    }

    public function blog_details($slug)
    {

        $post = Post::where('slug', $slug)->first();

        if ($post) {
            $related_posts = Post::inRandomOrder()->where('category_id', '=', $post->category_id)
                                                  ->where('id', '!=', $post->id)
                                                  ->take(2)
                                                  ->get();

            $category = Category::findOrFail($post->category_id);
            $categories = Category::orderBy('created_at', 'desc')->get();
            $tags = Tag::orderBy('created_at', 'desc')->get();

            $tag_ids = [];
            foreach($post->tags as $potag) {
                array_push($tag_ids, $potag->id);
            }
            
            if ($post) {
                
                $paragraphs = (array) json_decode($post->paragraph, true);
                $output = array_slice($paragraphs , 2);
                
            } else {
                abort(404);
            }

            $archive = Post::get()
                           ->groupBy(function($val) {
                                return Carbon::parse($val->created_at)->format('F Y');
                           });
            $popular_posts = Post::where('id', '!=', $post->id)
                                 ->orderBy('views', 'desc')
                                 ->take(3)
                                 ->get();
            
            $post->incrementViewsCount();

        } else {
            abort(404);
        }

        return view('frontend.blogs.blog-details', compact('post', 'related_posts', 'paragraphs', 'output', 'category', 'categories', 'tags', 'tag_ids', 'archive', 'popular_posts'));

    }

    public function category_blogs($slug)
    {
        $title = ucwords(str_replace('-', ' ', $slug));
        $category = Category::where('name', $title)->first();

        $cat_blogs = Post::where('category_id', $category->id)->orderBy('created_at', 'desc')->paginate(6);

        return view('frontend.blogs.category-blogs', compact('cat_blogs', 'category'));

    }

    public function tag_blogs($slug)
    {
        $name = ucwords(str_replace('-', ' ', $slug));
        $tag = Tag::where('tag', $name)->first();

        $db_tags = DB::table('post_tag')->where('tag_id', $tag->id)->paginate(3);
        
        return view('frontend.blogs.tag-blogs', compact('tag', 'db_tags'));

    }

    public function contact()
    {
        $sec_services = Service::where('type', 'Security Services')->orderBy('created_at')->get();
        $elec_services = Service::where('type', 'Electrical Services')->orderBy('created_at')->get();
        $airc_services = Service::where('type', '24/7 Site Cam')->orderBy('created_at')->get();
        return view('frontend.contact', compact('sec_services', 'elec_services', 'airc_services'));
    }

    public function submit_contact(Request $request)
    {
        $this->validate($request, [
            'name'      => 'required',
            'email'     => 'required',
            'service'   => 'required',
            'phone'     => 'required',
            'message'   => 'required',
        ]);


        $contact = new Contact();

        $contact->name = $request->name;
        $contact->email = $request->email;
        $contact->service_id = $request->service;
        $contact->phone = $request->phone;
        $contact->message = $request->message;

        $contact->save();

        Session::flash('success', 'Message Sent Successfully !');
        return redirect()->back();
    }

    public function shop(Request $request)
    {
        return view('frontend.coming-soon');
        // $min = request('min_price');
        // $max = request('max_price');
        // $search = request('search');

        // if(request('min_price') && request('max_price')) {
        //     $products = Product::whereBetween('price', [$min, $max])->orderBy('created_at', 'desc')->paginate(3)->withQueryString(); 
        //     $all = Product::whereBetween('price', [$min, $max])->get()->count();  
        // } else if(request('search')) {
        //     $products = Product::where('name', 'LIKE', "%{$search}%")
        //                  ->orderBy('created_at', 'desc')
        //                  ->paginate(3);
        //     $all = Product::where('name', 'LIKE', "%{$search}%")
        //                  ->get()
        //                  ->count();
        // } else {
        //     switch (request('filter')) {

        //         case 'high-to-low':
        //             $products = Product::orderBy('price', 'desc')->paginate(3)->withQueryString();
        //             $all = Product::all()->count();
        //             break;

        //         case 'low-to-high':
        //             $products = Product::orderBy('price', 'asc')->paginate(3)->withQueryString();
        //             $all = Product::all()->count();
        //             break;

        //         case 'newness':
        //             $products = Product::orderBy('created_at', 'desc')->paginate(3)->withQueryString();
        //             $all = Product::all()->count();
        //             break;

        //         default:
        //             $products = Product::orderBy('created_at', 'desc')->paginate(3)->withQueryString();
        //             $all = Product::all()->count();
        //             break;
        //     }

        // }
        
        // $pro_categories = ProductCategory::orderBy('created_at', 'desc')->get();

        // return view('frontend.shop.index', compact('products', 'pro_categories', 'all'));
    }

    public function category_shop($slug)
    {
        $title = ucwords(str_replace('-', ' ', $slug));
        $cat = ProductCategory::where('name', $title)->first();
        $pro_categories = ProductCategory::orderBy('created_at', 'desc')->get();

        switch (request('filter')) {

            case 'high-to-low':
                $products = Product::where('category_id', $cat->id)->orderBy('price', 'desc')->paginate(3)->withQueryString();
                break;

            case 'low-to-high':
                $products = Product::where('category_id', $cat->id)->orderBy('price', 'asc')->paginate(3)->withQueryString();
                break;

            case 'newness':
                $products = Product::where('category_id', $cat->id)->orderBy('created_at', 'desc')->paginate(3)->withQueryString();
                break;

            default:
                $products = Product::where('category_id', $cat->id)->orderBy('created_at', 'desc')->paginate(3)->withQueryString();
                break;

        }

        $all = Product::where('category_id', $cat->id)->count();

        return view('frontend.shop.category-shop', compact('products', 'cat', 'pro_categories', 'all'));

    }

    public function product_details($slug)
    {

        $product = Product::where('slug', $slug)->first();
        $category = ProductCategory::findOrFail($product->category_id);

        if($product) {
            $images = (array) json_decode($product->images, true);
            $attributes = json_decode($product->attributes, true);
        } else {
            abort(404);
        }

        return view('frontend.shop.product-details', compact('product', 'images', 'category', 'attributes'));

    }
    
    public function faq()
    {
        return view('frontend.faq');
    }
}
