<?php

namespace App\Http\Controllers\Cms;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;

use App\Models\Industry;

use Image;
use Session;
use Auth;

class IndustriesController extends Controller
{
    public function index()
    {
        $industries = Industry::orderBy('created_at', 'desc')->get();
        return view('backend.admin.industries.index')->with('industries', $industries);
    }

    public function create()
    {
        return view('backend.admin.industries.create');
    }

    public function store(Request $request)
    {
        $this->validate($request, [
            'short_name' => 'required|unique:industries',
            'title'      => 'required',
            'image'      => 'required',
            'include_title' => 'required',
            'include'    => 'required|array',
            'details'    => 'required',
        ]);


        $industry = new Industry();

        $industry->short_name = $request->short_name;
        $industry->title = $request->title;
        $industry->slug = str_slug($request->short_name);
        $industry->include_title = $request->include_title;
        $industry->details = $request->details;

        if ($request->hasFile('image')) {
            $image_tmp = $request->file('image');
            if ($image_tmp->isValid()) {
                $image_name = $image_tmp->getClientOriginalName();
                $extension = $image_tmp->getClientOriginalExtension();
                $image_new_name = $image_name.'-'.rand(111,99999).'.'.$extension;

                $original_image_path = 'assets/uploads/industries/'.$image_new_name;
                
                Image::make($image_tmp)->save($original_image_path);
                
                $industry->image = $image_new_name;
            }
        }

        $industry->includes  = json_encode($request->include);
        
        $industry->save();

        Session::flash('success', 'Industry Created Successfully !');
        
        return redirect()->route('all.industries');
    }

    public function edit($id)
    {

        $industry = Industry::findOrFail($id);
        
        $paragraphs = json_decode($industry->paragraph);
        $includes = json_decode($industry->includes);
        
        return view('backend.admin.industries.edit', compact('industry', 'paragraphs', 'includes'));

    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $this->validate($request, [
            'short_name' => 'required|unique:industries,short_name,'.$id,
            'title'      => 'required',
            'include_title' => 'required',
            'include'    => 'required|array',
            'details'    => 'required',
        ]);


        $industry = Industry::findOrFail($id);

        $industry->short_name = $request->short_name;
        $industry->title = $request->title;
        $industry->slug = str_slug($request->short_name);
        $industry->include_title = $request->include_title;
        $industry->details = $request->details;

        if ($request->hasFile('image')) {
            $image_tmp = $request->file('image');
            if ($image_tmp->isValid()) {
                $image_name = $image_tmp->getClientOriginalName();
                $extension = $image_tmp->getClientOriginalExtension();
                $image_new_name = $image_name.'-'.rand(111,99999).'.'.$extension;

                $original_image_path = 'assets/uploads/industries/'.$image_new_name;
                
                Image::make($image_tmp)->save($original_image_path);
                
                $industry->image = $image_new_name;
            }
        }

        $industry->includes  = json_encode($request->include);
        
        $industry->save();

        Session::flash('info', 'Industry Updated Successfully !');

        return redirect()->route('all.industries');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $industry = Industry::findOrFail($id);
        $industry->delete();

        Session::flash("error", "Industry deleted !");

        return redirect()->route('all.industries'); 
    }
}
