<?php

namespace App\Http\Controllers\Cms;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;

use App\Models\Project;

use Image;
use Session;
use Auth;

class ProjectsController extends Controller
{
    public function index()
    {
        $all = Project::orderBy('created_at', 'desc')->get();
        return view('backend.admin.projects.index', compact('all'));
    }

    public function create()
    {
        return view('backend.admin.projects.create');
    }

    public function store(Request $request)
    {

        $this->validate($request, [
            'title'     => 'required|unique:projects',
            'images'    => 'required|array',
            'details'   => 'required',
        ]);


        $project = new Project();

        $project->title = $request->title;
        $project->slug  = str_slug($request->title);
        $project->details = $request->details;

        $images_array = [];

        foreach($request->images as $image){
                
            $image_tmp = $image['project_image'];

            if ($image_tmp->isValid()) {
                $image_name = $image_tmp->getClientOriginalName();
                $extension = $image_tmp->getClientOriginalExtension();
                $image_new_name = $image_name.'-'.rand(11,9999999).'.'.$extension;

                $original_image_path = 'assets/uploads/projects/'.$image_new_name;
                
                // Image::make($image_tmp)->save($original_image_path);
                Image::make($image_tmp)->resize(520,600)->save($original_image_path);
                
                $images_array[$image['image_title']] = $image_new_name;
            }

        }

        $project->images = json_encode($images_array);
        
        $project->save();

        Session::flash('success', 'Project Created Successfully !');
        return redirect()->route('all.projects');
    }

    public function edit($id)
    {
        $project = Project::findOrFail($id);

        $images = json_decode($project->images);

        return view('backend.admin.projects.edit', compact('project', 'images'));
    }

    public function update(Request $request, $id)
    {
        
        $this->validate($request, [
            'details'   => 'required',
            'title'     => 'required|unique:projects,title,'.$id
        ]);


        $project = Project::findOrFail($id);

        $project->title = $request->title;
        $project->slug  = str_slug($request->title);
        $project->details = $request->details;

        $previous_images = (array) json_decode($project->images, true);

        $images_array = [];

        if($request->images[0]['image_title']) {
            foreach($request->images as $image){
                    
                $image_tmp = $image['project_image'];

                if ($image_tmp->isValid()) {
                    $image_name = $image_tmp->getClientOriginalName();
                    $extension = $image_tmp->getClientOriginalExtension();
                    $image_new_name = $image_name.'-'.rand(11,9999999).'.'.$extension;

                    $original_image_path = 'assets/uploads/projects/'.$image_new_name;
                    
                    Image::make($image_tmp)->save($original_image_path);
                    
                    $images_array[$image['image_title']] = $image_new_name;
                }

            }

            $new_array = array_merge($images_array, $previous_images);

        } else {
            $new_array = $previous_images;
        }

        $project->images = json_encode($new_array);
        
        $project->save();

        Session::flash('info', 'Project Updated Successfully !');
        return redirect()->route('all.projects');
    }

    public function destroy($id)
    {
        
        $project = Project::findOrFail($id);
        $project->delete();

        Session::flash('error', 'Project Deleted !');
        return redirect()->route('all.projects');

    }
}
