<?php

namespace App\Http\Controllers\Ums;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;

use App\Models\Service;
use App\Models\AppSettings;
use App\Models\Contact;
use App\Models\Project;
use App\Models\Post;
use App\Models\Category;
use App\Models\Tag;

use Image;
use Session;
use Auth;

class AdminToolsController extends Controller
{
    public function dashboard()
    {
        $services = Service::all()->count();
        $contacts = Contact::all()->count();
        $projects = Project::all()->count();
        $posts    = Post::all()->count();
        $replied  = Contact::where('status', 'Replied')->get()->count();
        $nreplied = Contact::where('status', 'Not replied')->get()->count();

    	return view('backend.admin.index', compact('contacts', 'services', 'projects', 'posts', 'replied', 'nreplied'));
    }

    public function all_services()
    {
    	$all = Service::orderBy('created_at', 'desc')->get();
    	return view('backend.admin.services.index', compact('all'));
    }

    public function add_service()
    {
        return view('backend.admin.services.create');
    }

    public function store_service(Request $request)
    {
        $this->validate($request, [
            'name'                 => 'required|unique:services',
            'service_image'        => 'required',
            'service_description'  => 'required',
            'solution'             => 'required|array',
        ]);


        $service = new Service();

        $service->added_by = Auth::id();
        $service->name = $request->name;
        $service->description = $request->service_description;
        $service->type = $request->type;

        if ($request->hasFile('service_image')) {
            $image_tmp = $request->file('service_image');
            if ($image_tmp->isValid()) {
                $image_name = $image_tmp->getClientOriginalName();
                $extension = $image_tmp->getClientOriginalExtension();
                $image_new_name = $image_name.'-'.rand(111,99999).'.'.$extension;

                $original_image_path = 'assets/uploads/services/'.$image_new_name;
                
                Image::make($image_tmp)->save($original_image_path);
                
                $service->image = $image_new_name;
            }
        }

        $service->solutions = json_encode($request->solution);

        $service->save();

        Session::flash('success', 'Service Created Successfully !');
        return redirect()->back();
    }

    public function edit_service($id)
    {
        $service = Service::findOrFail($id);

        $solutions = json_decode($service->solutions);

        return view('backend.admin.services.edit', compact('service', 'solutions'));
    }

    public function update_service(Request $request, $id)
    {
        
        $this->validate($request, [
            'service_description'  => 'required',
            'solution'             => 'required|array',
            'name'                 => 'required|unique:services,name,'.$id
        ]);

        $service = Service::findOrFail($id);

        $service->added_by = $service->added_by;
        $service->name = $request->name;
        $service->description = $request->service_description;
        $service->type = $request->type;

        if ($request->hasFile('service_image')) {
            $image_tmp = $request->file('service_image');
            if ($image_tmp->isValid()) {
                $image_name = $image_tmp->getClientOriginalName();
                $extension = $image_tmp->getClientOriginalExtension();
                $image_new_name = $image_name.'-'.rand(111,99999).'.'.$extension;

                $original_image_path = 'assets/uploads/services/'.$image_new_name;
                
                Image::make($image_tmp)->save($original_image_path);
                
                $service->image = $image_new_name;
            }
        }

        $service->solutions = json_encode($request->solution);

        $service->save();

        Session::flash('success', 'Service Updated Successfully !');
        return redirect()->route('all.services');
    }

    public function destroy_service($id)
    {
        
        $service = Service::findOrFail($id);
        $service->delete();

        Session::flash('error', 'Service Deleted !');
        return redirect()->route('all.services');

    }

    public function app_settings()
    {
        $settings = AppSettings::findOrFail(1);
        return view('backend.admin.settings', compact('settings'));
    }

    public function slider_images()
    {
        $settings = AppSettings::findOrFail(1);
        return view('backend.admin.slider-images', compact('settings'));
    }

    public function update_settings(Request $request)
    {
        
        $this->validate($request, [
            'phone'  => 'required',
            'address'  => 'required',
            'email'  => 'required',
            'facebook'  => 'required',
            'instagram'  => 'required',
            'google'  => 'required',
        ]);

        $settings = AppSettings::findOrFail(1);

        $settings->phone = $request->phone;
        $settings->address = $request->address;
        $settings->email = $request->email;
        $settings->facebook = $request->facebook;
        $settings->instagram = $request->instagram;
        $settings->google = $request->google;

        
        $settings->save();

        Session::flash('success', 'Service Updated Successfully !');
        return redirect()->back();
    }

    public function change_slider_images(Request $request)
    {
        $settings = AppSettings::findOrFail(1);

        if ($request->hasFile('slider_1')) {
            $image_tmp = $request->file('slider_1');
            if ($image_tmp->isValid()) {
                $image_name = $image_tmp->getClientOriginalName();
                $extension = $image_tmp->getClientOriginalExtension();
                $image_new_name = $image_name.'-'.rand(111,99999).'.'.$extension;

                $original_image_path = 'assets/uploads/sliders/'.$image_new_name;
                
                Image::make($image_tmp)->save($original_image_path);
                
                $settings->slider_1 = $image_new_name;
            }
        }

        if ($request->hasFile('slider_2')) {
            $image_tmp = $request->file('slider_2');
            if ($image_tmp->isValid()) {
                $image_name = $image_tmp->getClientOriginalName();
                $extension = $image_tmp->getClientOriginalExtension();
                $image_new_name = $image_name.'-'.rand(111,99999).'.'.$extension;

                $original_image_path = 'assets/uploads/sliders/'.$image_new_name;
                
                Image::make($image_tmp)->save($original_image_path);
                
                $settings->slider_2 = $image_new_name;
            }
        }

        if ($request->hasFile('slider_3')) {
            $image_tmp = $request->file('slider_3');
            if ($image_tmp->isValid()) {
                $image_name = $image_tmp->getClientOriginalName();
                $extension = $image_tmp->getClientOriginalExtension();
                $image_new_name = $image_name.'-'.rand(111,99999).'.'.$extension;

                $original_image_path = 'assets/uploads/sliders/'.$image_new_name;
                
                Image::make($image_tmp)->save($original_image_path);
                
                $settings->slider_3 = $image_new_name;
            }
        }

        $settings->save();

        Session::flash('info', 'Slider Image(s) Updated Successfully !');
        return redirect()->back();

    }

    public function replied_contacts()
    {
        $all = Contact::where('status', 'Replied')->orderBy('created_at', 'desc')->get();
        return view('backend.admin.contacts.replied', compact('all'));
    }

    public function unreplied_contacts()
    {
        $all = Contact::where('status', 'Not replied')->orderBy('created_at', 'desc')->get();
        return view('backend.admin.contacts.unreplied', compact('all'));
    }

    public function view_message($id)
    {
        $contact = Contact::findOrFail($id);
        $service = Service::findOrFail($contact->service_id);

        $sent = $contact->created_at->format('d M, Y - h:i A');

        $date_time = strtotime($contact->replied_at);
        $replied = date('d M, Y - h:i A', $date_time);

        return view('backend.admin.contacts.view', compact('contact', 'service', 'sent', 'replied'));
    }

    public function mark_replied($id)
    {
        $contact = Contact::findOrFail($id);
        $contact->status = 'Replied';
        $contact->replied_at = now();
        $contact->save();
        
        Session::flash('info', 'Contact marked as Replied successfully !');
        return redirect()->back();
    }

    public function mark_unreplied($id)
    {
        $contact = Contact::findOrFail($id);
        $contact->status = 'Not replied';
        $contact->replied_at = null;
        $contact->save();
        
        Session::flash('warning', 'Contact marked as Unreplied !');
        return redirect()->back();
    }

    public function destroy_contact($id)
    {
        
        $contact = Contact::findOrFail($id);
        $contact->delete();

        Session::flash('error', 'Contact Message Deleted !');
        return redirect()->back();

    }

}
