@extends('layouts.master')
@section('title', 'Add New Blog Post')

@section('content')
    <!-- ========================== Page Content ==================================== -->
    <div class="page-content">
        <div class="container-fluid">

            <!-- start page title -->
            <div class="row">
                <div class="col-12">
                    <div class="page-title-box d-sm-flex align-items-center justify-content-between">
                        <h4 class="mb-sm-0 font-size-18"> Add New Blog Post</h4>

                        <div class="page-title-right">
                            <ol class="breadcrumb m-0">
                                <li class="breadcrumb-item"><a href="{{ route('dashboard') }}">Dashboard </a></li>
                                <li class="breadcrumb-item active" style="color: #74788d;">Add New Blog Post</li>
                            </ol>
                        </div>

                    </div>
                </div>
            </div>
            <!-- end page title -->

            <div class="row">
                <div class="col-lg-12">
                    
                    @if(count($errors) > 0)
                        <div class="alert alert-dismissible fade show color-box bg-danger bg-gradient p-4" role="alert">
                            <x-jet-validation-errors class="mb-4 my-2 text-white" />
                            <button type="button" class="btn-close" data-bs-dismiss="alert" aria-label="Close"></button>
                        </div>
                    @endif
                        
                </div>
            </div>

            <div class="row">
                <div class="col-lg-12">
                    <div class="card">
                        <div class="card-body">

                            <form class="repeater needs-validation" action="{{ route('store.post') }}" method="post" enctype="multipart/form-data" novalidate="">
                            @csrf

                                <div class="row">
                                    <div class="col-md-6">
                                        <div class="mb-3 position-relative">
                                            <label for="validationTooltip01" class="form-label">Post title</label>
                                            <input type="text" class="form-control" id="validationTooltip01" placeholder="Enter post title" name="title" value="{{ old('title') }}" required="">

                                            <div class="valid-tooltip">
                                                Looks good!
                                            </div>

                                            <div class="invalid-tooltip">
                                                Please enter post title.
                                            </div>
                                        </div>
                                    </div>

                                    <div class="col-md-6">
                                        <div class="mb-3 position-relative">
                                            <label for="validationTooltip02" class="form-label">Upload Image</label>
                                            <input type="file" class="form-control" id="validationTooltip02" name="image" required> 

                                            <div class="valid-tooltip">
                                                Looks good!
                                            </div>

                                            <div class="invalid-tooltip">
                                                Please upload post image.
                                            </div> 
                                        </div>
                                    </div>

                                </div>

                                <br>

                                <div class="row">
                                    <div class="col-md-6">
                                        <div class="mb-3 position-relative">
                                            <label for="validationTooltip100" class="form-label">Post Author</label>
                                            <input type="text" class="form-control" id="validationTooltip100" placeholder="Enter post author" name="author" value="{{ old('author') }}" required="">

                                            <div class="valid-tooltip">
                                                Looks good!
                                            </div>

                                            <div class="invalid-tooltip">
                                                Please enter post author.
                                            </div>
                                        </div>
                                    </div>

                                    <div class="col-md-6">
                                        <div class="mb-3 position-relative">
                                            <label for="validationTooltip12" class="form-label">Select Category</label>
                                            <select class="form-control select2" id="validationTooltip12" name="category_id" required="">
                                            
                                                <option value="">Select Any Category</option>
                                               
                                                    @foreach($categories as $category)
                                                        <option value="{{ $category->id }}" {{ old('category_id') == $category->id ? "selected" : "" }}>{{ $category->name }}</option>
                                                    @endforeach

                                            </select>

                                            <div class="valid-tooltip">
                                                Looks good!
                                            </div>

                                            <div class="invalid-tooltip">
                                                Please select any category from the list.
                                            </div>
                                        </div>
                                    </div>

                                </div>

                                <br>

                                <div class="row">
                                    <div class="col-md-12">
                                        <div class="mb-3 position-relative">
                                            <label for="summernote_text" class="form-label">Quote (Optional)</label>
                                            <textarea id="summernote_text" rows="5" name="quote" class="form-control">{{ old('quote') }}</textarea>
                                            <div class="valid-tooltip">
                                                Looks good!
                                            </div>

                                            <div class="invalid-tooltip">
                                                Please enter quote.
                                            </div>
                                        </div>
                                    </div>
                                </div>

                                <br>

                                <div class="row">
                                    <div class="col-md-12">
                                        <div class="mb-3 position-relative">
                                            <label class="form-label">Select Related Tags</label>

                                            <select class="select2 form-control select2-multiple" name="tags[]" multiple="multiple" required data-placeholder="Choose Tags...">
                                                @foreach($tags as $tag)
                                                    <option value="{{ $tag->id }}">{{ $tag->tag }}</option>
                                                @endforeach    
                                            </select>

                                            <div class="valid-tooltip">
                                                Looks good!
                                            </div>

                                            <div class="invalid-tooltip">
                                                Please enter tags from the list.
                                            </div>
                                        </div>
                                    </div>
                                </div>

                                <br>

                                <div class="row">
                                    <div class="col-md-12">
                                        <div class="mb-3 position-relative">
                                            <label for="solutions" class="form-label">Add New Paragraph </label>
                                            <div data-repeater-list="paragraph">
                                                <div data-repeater-item class="row">
                                                    
                                                    <div class="mb-3 col-lg-11">
                                                        
                                                        <textarea id="paragraph_note" placeholder="Enter Paragraph" name="paragraph_note" rows="8" class="form-control" required></textarea>
                                                    </div>
                                                    
                                                    <div class="mb-3 col-lg-1 align-self-center">
                                                        <div class="d-grid">
                                                            <input data-repeater-delete type="button" class="btn btn-danger" value="Delete"/>
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>

                                            <input data-repeater-create type="button" class="btn btn-light mt-3 mt-lg-0" value="Click to add new"/>

                                        </div>
                                    </div>

                                </div>


                                <div class="row">
                                    
                                    <div class="col-md-12">
                                        
                                        <button class="btn btn-primary" style="margin-top: 6px !important; width: 100% !important" type="submit">Save New Blog Post</button>
                                        
                                    </div>
                            
                                </div>

                            </form>

                        </div>
                        <!-- end card body -->
                    </div>
                    <!-- end card -->
                </div>
                <!-- end col -->
            </div>
            <!-- end row -->

        </div> <!-- container-fluid -->
    </div>
    <!-- End Page-content -->                
                
@endsection

@section('scripts')
    {{-- <script type="text/javascript">
        $('#summernote_text').summernote({
            placeholder: 'Enter service description',
            tabsize: 2,
            height: 120,
            toolbar: [
              ['style', ['style']],
              ['font', ['bold', 'underline', 'clear']],
              ['color', ['color']],
              ['para', ['ul', 'ol', 'paragraph']],
              ['table', ['table']],
              ['insert', ['link', 'picture', 'video']],
              ['view', ['fullscreen', 'codeview', 'help']]
            ],
        });
    </script> --}}
@endsection

@section('styles')
    {{-- <style type="text/css">
        .note-editing-area {
            background: white !important;
        }
    </style> --}}
@endsection

