@extends('layouts.master')
@section('title', 'Add New Product')

@section('content')
    <!-- ========================== Page Content ==================================== -->
    <div class="page-content">
        <div class="container-fluid">

            <!-- start page title -->
            <div class="row">
                <div class="col-12">
                    <div class="page-title-box d-sm-flex align-items-center justify-content-between">
                        <h4 class="mb-sm-0 font-size-18"> Add New Product</h4>

                        <div class="page-title-right">
                            <ol class="breadcrumb m-0">
                                <li class="breadcrumb-item"><a href="{{ route('dashboard') }}">Dashboard </a></li>
                                <li class="breadcrumb-item active" style="color: #74788d;">Add New Product</li>
                            </ol>
                        </div>

                    </div>
                </div>
            </div>
            <!-- end page title -->

            <div class="row">
                <div class="col-lg-12">
                    
                    @if(count($errors) > 0)
                        <div class="alert alert-dismissible fade show color-box bg-danger bg-gradient p-4" role="alert">
                            <x-jet-validation-errors class="mb-4 my-2 text-white" />
                            <button type="button" class="btn-close" data-bs-dismiss="alert" aria-label="Close"></button>
                        </div>
                    @endif
                        
                </div>
            </div>

            <div class="row">
                <div class="col-lg-12">
                    <div class="card">
                        <div class="card-body">

                            <form class="repeater needs-validation" action="{{ route('store.product') }}" method="post" enctype="multipart/form-data" novalidate="">
                            @csrf

                                <div class="row">

                                    <div class="col-md-6">
                                        <div class="mb-3 position-relative">
                                            <label for="validationTooltip01" class="form-label">Product Name</label>
                                            <input type="text" class="form-control" id="validationTooltip01" placeholder="Enter product name" name="name" value="{{ old('name') }}" required="">

                                            <div class="valid-tooltip">
                                                Looks good!
                                            </div>

                                            <div class="invalid-tooltip">
                                                Please enter product name.
                                            </div>
                                        </div>
                                    </div>

                                    <div class="col-md-6">
                                        <div class="mb-3 position-relative">
                                            <label for="validationTooltip02" class="form-label">Upload Image(s)</label>
                                            <input type="file" class="form-control" id="validationTooltip02" name="images[]" multiple required> 

                                            <div class="valid-tooltip">
                                                Looks good!
                                            </div>

                                            <div class="invalid-tooltip">
                                                Please upload product image.
                                            </div> 
                                        </div>
                                    </div>

                                </div>

                                <br>

                                <div class="row">

                                    <div class="col-md-6">
                                        <div class="mb-3 position-relative">
                                            <label for="validationTooltip12" class="form-label">Select Product Category</label>
                                            <select class="form-control select2" id="validationTooltip12" name="category_id" required="">
                                            
                                                <option value="">Select Any Category</option>
                                               
                                                    @foreach($pro_categories as $category)
                                                        <option value="{{ $category->id }}" {{ old('category_id') == $category->id ? "selected" : "" }}>{{ $category->name }}</option>
                                                    @endforeach

                                            </select>

                                            <div class="valid-tooltip">
                                                Looks good!
                                            </div>

                                            <div class="invalid-tooltip">
                                                Please select any category from the list.
                                            </div>
                                        </div>
                                    </div>

                                    <div class="col-md-6">
                                        <div class="mb-3 position-relative">
                                            <label for="validationTooltip100" class="form-label">Price (USD)</label>
                                            <input type="number" step="0.01" class="form-control" id="validationTooltip100" placeholder="Enter product price" name="price" value="{{ old('price') }}" required="">

                                            <div class="valid-tooltip">
                                                Looks good!
                                            </div>

                                            <div class="invalid-tooltip">
                                                Please enter valid product price.
                                            </div>
                                        </div>
                                    </div>

                                </div>

                                <br>

                                <div class="row">
                                    <div class="col-md-12">
                                        <div class="mb-3 position-relative">
                                            <label for="short" class="form-label">Short Description </label>
                                            <textarea id="short" rows="5" name="description" class="form-control" required>{{ old('description') }}</textarea>
                                            <div class="valid-tooltip">
                                                Looks good!
                                            </div>

                                            <div class="invalid-tooltip">
                                                Please enter short description.
                                            </div>
                                        </div>
                                    </div>
                                </div>

                                <br>

                                <div class="row">
                                    <div class="col-md-12">
                                        <div class="mb-3 position-relative">
                                            <label for="additional" class="form-label">Additional Information (Optional)</label>
                                            <textarea id="additional" rows="3" name="additional_info" class="form-control">{{ old('additional_info') }}</textarea>
                                            <div class="valid-tooltip">
                                                Looks good!
                                            </div>

                                            <div class="invalid-tooltip">
                                                Please enter additional info.
                                            </div>
                                        </div>
                                    </div>
                                </div>

                                <br>

                                <div class="row">
                                    <div class="col-md-12">
                                        <div class="mb-3 position-relative">
                                            <label for="payment" class="form-label">Payment Information (Optional)</label>
                                            <textarea id="payment" rows="3" name="payment_info" class="form-control">{{ old('payment_info') }}</textarea>
                                            <div class="valid-tooltip">
                                                Looks good!
                                            </div>

                                            <div class="invalid-tooltip">
                                                Please enter payment info.
                                            </div>
                                        </div>
                                    </div>
                                </div>

                                <br>

                                <div class="row">
                                    <div class="col-md-12">
                                        <div class="mb-3 position-relative">
                                            <label for="attributes" class="form-label">Add Attributes</label>
                                            <div data-repeater-list="attributes">
                                                <div data-repeater-item class="row">
                                                    <div  class="mb-3 col-lg-4">
                                        
                                                        <input type="text" id="attribute_name" name="attribute_name" class="form-control" placeholder="Attribute Name" required/>
                                                    </div>

                                                    <div class="mb-3 col-lg-6">
                                                        
                                                        <input type="text" id="attribute_value" name="attribute_value" class="form-control" placeholder="Attribute Value" required/>
                                                    </div>
                                                    
                                                    <div class="mb-3 col-lg-2 align-self-center">
                                                        <div class="d-grid">
                                                            <input data-repeater-delete type="button" class="btn btn-danger" value="Delete"/>
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>

                                            <input data-repeater-create type="button" class="btn btn-light mt-3 mt-lg-0" value="Click to add new"/>

                                        </div>
                                    </div>

                                </div>


                                <div class="row">
                                    
                                    <div class="col-md-12">
                                        
                                        <button class="btn btn-primary" style="margin-top: 6px !important; width: 100% !important" type="submit">Save New Product</button>
                                        
                                    </div>
                            
                                </div>

                            </form>

                        </div>
                        <!-- end card body -->
                    </div>
                    <!-- end card -->
                </div>
                <!-- end col -->
            </div>
            <!-- end row -->

        </div> <!-- container-fluid -->
    </div>
    <!-- End Page-content -->                
                
@endsection
