@extends('layouts.master')
@section('title', 'Update Product')

@section('content')
    <!-- ========================== Page Content ==================================== -->
    <div class="page-content">
        <div class="container-fluid">

            <!-- start page title -->
            <div class="row">
                <div class="col-12">
                    <div class="page-title-box d-sm-flex align-items-center justify-content-between">
                        <h4 class="mb-sm-0 font-size-18"> Update Product</h4>

                        <div class="page-title-right">
                            <ol class="breadcrumb m-0">
                                <li class="breadcrumb-item"><a href="{{ route('dashboard') }}">Dashboard </a></li>
                                <li class="breadcrumb-item active" style="color: #74788d;">Update Product</li>
                            </ol>
                        </div>

                    </div>
                </div>
            </div>
            <!-- end page title -->

            <div class="row">
                <div class="col-lg-12">
                    
                    @if(count($errors) > 0)
                        <div class="alert alert-dismissible fade show color-box bg-danger bg-gradient p-4" role="alert">
                            <x-jet-validation-errors class="mb-4 my-2 text-white" />
                            <button type="button" class="btn-close" data-bs-dismiss="alert" aria-label="Close"></button>
                        </div>
                    @endif
                        
                </div>
            </div>

            <div class="row">
                <div class="col-lg-12">
                    <div class="card">
                        <div class="card-body">

                            <form class="repeater needs-validation" action="{{ route('update.product', $product->id) }}" method="post" enctype="multipart/form-data" novalidate="">
                            @csrf

                                <div class="row">
                                    <label for="already" class="form-label">Already Added Product Image(s)</label>

                                    @foreach(json_decode($product->images) as $image)

                                        <div class="col-md-3">
                                            <div class="mb-3 position-relative">
                                                <div class="zoom-gallery d-flex flex-wrap">
                                                    <a href="{{ asset('assets/uploads/products/'.$image) }}" title="{{ $image }}">
                                                        <img src="{{ asset('assets/uploads/products/'.$image) }}" alt="" style="height: 130px !important; width: 180px !important;" class="rounded mr-2">
                                                    </a>
                                                </div>
                                            </div>
                                        </div>

                                    @endforeach

                                </div>

                                <br>

                                <div class="row">

                                    <div class="col-md-6">
                                        <div class="mb-3 position-relative">
                                            <label for="validationTooltip01" class="form-label">Product Name</label>
                                            <input type="text" class="form-control" id="validationTooltip01" placeholder="Enter product name" name="name" value="{{ old('name', $product->name) }}" required="">

                                            <div class="valid-tooltip">
                                                Looks good!
                                            </div>

                                            <div class="invalid-tooltip">
                                                Please enter product name.
                                            </div>
                                        </div>
                                    </div>

                                    <div class="col-md-6">
                                        <div class="mb-3 position-relative">
                                            <label for="validationTooltip02" class="form-label">Upload More Image(s)</label>
                                            <input type="file" multiple class="form-control" id="validationTooltip02" name="images[]"> 

                                            <div class="valid-tooltip">
                                                Looks good!
                                            </div>

                                            <div class="invalid-tooltip">
                                                Please upload product image.
                                            </div> 
                                        </div>
                                    </div>

                                </div>

                                <br>

                                <div class="row">
                                    
                                    <div class="col-md-6">
                                        <div class="mb-3 position-relative">
                                            <label for="validationTooltip12" class="form-label">Selected Product Category</label>
                                            <select class="form-control select2" id="validationTooltip12" name="category_id" required="">
                                            
                                                <option value="">Select Any Category</option>
                                               
                                                    @foreach($pro_categories as $category)
                                                        <option value="{{ $category->id }}" {{ old('category_id', $product->category_id) == $category->id ? "selected" : "" }}>{{ $category->name }}</option>
                                                    @endforeach

                                            </select>

                                            <div class="valid-tooltip">
                                                Looks good!
                                            </div>

                                            <div class="invalid-tooltip">
                                                Please select any category from the list.
                                            </div>
                                        </div>
                                    </div>

                                    <div class="col-md-6">
                                        <div class="mb-3 position-relative">
                                            <label for="validationTooltip100" class="form-label">Price (USD)</label>
                                            <input type="number" step="0.01" class="form-control" id="validationTooltip100" placeholder="Enter product price" name="price" value="{{ old('price', $product->price) }}" required="">

                                            <div class="valid-tooltip">
                                                Looks good!
                                            </div>

                                            <div class="invalid-tooltip">
                                                Please enter valid product price.
                                            </div>
                                        </div>
                                    </div>

                                </div>

                                <br>

                                <div class="row">
                                    <div class="col-md-12">
                                        <div class="mb-3 position-relative">
                                            <label for="short" class="form-label">Short Description </label>
                                            <textarea id="short" rows="5" name="description" class="form-control" required>{{ old('description', $product->description) }}</textarea>
                                            <div class="valid-tooltip">
                                                Looks good!
                                            </div>

                                            <div class="invalid-tooltip">
                                                Please enter short description.
                                            </div>
                                        </div>
                                    </div>
                                </div>

                                <br>

                                <div class="row">
                                    <div class="col-md-12">
                                        <div class="mb-3 position-relative">
                                            <label for="additional" class="form-label">Additional Information (Optional)</label>
                                            <textarea id="additional" rows="3" name="additional_info" class="form-control">{{ old('additional_info', $product->additional_info) }}</textarea>
                                            <div class="valid-tooltip">
                                                Looks good!
                                            </div>

                                            <div class="invalid-tooltip">
                                                Please enter additional info.
                                            </div>
                                        </div>
                                    </div>
                                </div>

                                <br>

                                <div class="row">
                                    <div class="col-md-12">
                                        <div class="mb-3 position-relative">
                                            <label for="payment" class="form-label">Payment Information (Optional)</label>
                                            <textarea id="payment" rows="3" name="payment_info" class="form-control">{{ old('payment_info', $product->payment_info) }}</textarea>
                                            <div class="valid-tooltip">
                                                Looks good!
                                            </div>

                                            <div class="invalid-tooltip">
                                                Please enter payment info.
                                            </div>
                                        </div>
                                    </div>
                                </div>

                                <br>

                                <div class="row">
                                    <div class="col-md-12">
                                        <div class="mb-3 position-relative">
                                            <label for="attributes" class="form-label">Add/Edit Attributes</label>
                                            <div data-repeater-list="attributes">
                                                
                                                @foreach($attributes as $key => $value)    
                                                    <div data-repeater-item class="row">
                                                        <div  class="mb-3 col-lg-4">
                                            
                                                            <input type="text" id="attribute_name" name="attribute_name" class="form-control" value="{{ $key }}" placeholder="Attribute Name" required/>
                                                        </div>

                                                        <div class="mb-3 col-lg-6">
                                                            
                                                            <input type="text" id="attribute_value" name="attribute_value" class="form-control" value="{{ $value }}" placeholder="Attribute Value" required/>
                                                        </div>
                                                        
                                                        <div class="mb-3 col-lg-2 align-self-center">
                                                            <div class="d-grid">
                                                                <input data-repeater-delete type="button" class="btn btn-danger" value="Delete"/>
                                                            </div>
                                                        </div>
                                                    </div>
                                                @endforeach

                                            </div>

                                            <input data-repeater-create type="button" class="btn btn-light mt-3 mt-lg-0" value="Click to add new"/>

                                        </div>
                                    </div>

                                </div>


                                <div class="row">
                                    
                                    <div class="col-md-12">
                                        
                                        <button class="btn btn-primary" style="margin-top: 6px !important; width: 100% !important" type="submit">Update Product</button>
                                        
                                    </div>
                            
                                </div>

                            </form>

                        </div>
                        <!-- end card body -->
                    </div>
                    <!-- end card -->
                </div>
                <!-- end col -->
            </div>
            <!-- end row -->

        </div> <!-- container-fluid -->
    </div>
    <!-- End Page-content -->                
                
@endsection

@section('scripts')
    {{-- <script type="text/javascript">
        $('#summernote_text').summernote({
            placeholder: 'Enter service description',
            tabsize: 2,
            height: 120,
            toolbar: [
              ['style', ['style']],
              ['font', ['bold', 'underline', 'clear']],
              ['color', ['color']],
              ['para', ['ul', 'ol', 'paragraph']],
              ['table', ['table']],
              ['insert', ['link', 'picture', 'video']],
              ['view', ['fullscreen', 'codeview', 'help']]
            ],
        });
    </script> --}}
@endsection

@section('styles')
    {{-- <style type="text/css">
        .note-editing-area {
            background: white !important;
        }
    </style> --}}
@endsection

