<?php

use Illuminate\Support\Facades\Route;

use App\Http\Controllers\Cms\RoleController;
use App\Http\Controllers\Ums\AdminToolsController;
use App\Http\Controllers\Cms\ThemeController;
use App\Http\Controllers\Ums\ProfileController;
use App\Http\Controllers\Cms\TagsController;
use App\Http\Controllers\Cms\CategoriesController;
use App\Http\Controllers\Cms\PostsController;
use App\Http\Controllers\Cms\ProjectsController;
use App\Http\Controllers\Cms\FrontendController;
use App\Http\Controllers\Cms\ProductCategoriesController;
use App\Http\Controllers\Cms\ProductsController;
use App\Http\Controllers\Cms\IndustriesController;
use App\Http\Controllers\Cms\CartController;
use App\Http\Controllers\Payment\StripeController;


/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/

Route::get('/clear-cache', function () {

    \Artisan::call('optimize:clear');

    dd("Cache is cleared");

});

 

Route::get('/getsections', [FrontendController::class, 'get_section']);

Route::get('/', [FrontendController::class, 'home'])->name('home');
Route::get('/about-us', [FrontendController::class, 'about'])->name('about');
Route::get('/contact-us', [FrontendController::class, 'contact'])->name('contact');
Route::post('/submit-contact', [FrontendController::class, 'submit_contact'])->name('submit.contact');
Route::get('/faq', [FrontendController::class, 'faq'])->name('faq');

Route::get('/security-services', [FrontendController::class, 'security_services'])->name('security.services');
Route::get('/electrical-services', [FrontendController::class, 'electrical_services'])->name('electrical.services');
Route::get('/24-7-site-cam-services', [FrontendController::class, 'air_conditioning'])->name('airconditioning.services');

Route::get('/service/security/{slug}', [FrontendController::class, 'security_service_details'])->name('security.service.details');
Route::get('/service/electrical/{slug}', [FrontendController::class, 'electrical_service_details'])->name('electrical.service.details');
Route::get('/service/24-7-site-cam/{slug}', [FrontendController::class, 'air_conditioning_details'])->name('airconditioning.service.details');

Route::get('/projects', [FrontendController::class, 'projects'])->name('projects');
// Route::get('/project/{slug}', [FrontendController::class, 'project_details'])->name('project.details');

Route::get('/news', [FrontendController::class, 'blogs'])->name('blogs');
Route::get('/news/{slug}', [FrontendController::class, 'blog_details'])->name('blog.details');
Route::get('/news/category/{category}', [FrontendController::class, 'category_blogs'])->name('blog.category');
Route::get('/news/tag/{tag}', [FrontendController::class, 'tag_blogs'])->name('blog.tag');

Route::get('/industries', [FrontendController::class, 'industries'])->name('industry');
Route::get('/industry/{slug}', [FrontendController::class, 'industry_details'])->name('industry.details');

Route::get('/shop', [FrontendController::class, 'shop'])->name('shop');
// Route::get('/shop/{category}', [FrontendController::class, 'category_shop'])->name('shop.category');
// Route::get('/product/{slug}', [FrontendController::class, 'product_details'])->name('product.details');

// Route::get('/shop/product/cart', [CartController::class, 'cart_list'])->name('shop.cart.list');
// Route::post('/shop/product/cart', [CartController::class, 'add_to_cart'])->name('shop.cart.store');
// Route::post('/shop/cart/update', [CartController::class, 'update_cart'])->name('shop.cart.update');
// Route::post('/shop/cart/remove', [CartController::class, 'remove_cart'])->name('shop.cart.remove');
// Route::post('/shop/cart/clear', [CartController::class, 'clear_all_cart'])->name('shop.cart.clear');

// Route::get('/shop/cart/checkout', [CartController::class, 'shop_checkout'])->name('shop.checkout');
// Route::get('/shop/checkout/make-payment', [CartController::class, 'make_payment'])->name('make.payment');

// Route::post('/stripe/checkout/payment', [StripeController::class, 'make_stripe_payment'])->name('make.stripe.payment');


// Route::get('/generate-role', [RoleController::class, 'generate_role'])->name('generate.role');

Route::middleware(['auth:sanctum', 'verified'])->group(function () {
	Route::post('/save-theme', [ThemeController::class, 'select_theme'])->name('select.theme');

	Route::post('/save/basic-info', [ProfileController::class, 'save_basic_info'])->name('save.basic.info');
	Route::post('/save/change-password', [ProfileController::class, 'change_auth_password'])->name('change.auth.password');
		
	Route::group(['prefix' => 'administrator'], function(){
		Route::get('/dashboard', [AdminToolsController::class, 'dashboard'])->name('dashboard');

		Route::get('/all-services', [AdminToolsController::class, 'all_services'])->name('all.services');
		Route::get('/create-service', [AdminToolsController::class, 'add_service'])->name('add.service');
		Route::post('/store-service', [AdminToolsController::class, 'store_service'])->name('store.service');
		Route::get('/service/edit/{id}', [AdminToolsController::class, 'edit_service'])->name('edit.service');
		Route::post('/service/update/{id}', [AdminToolsController::class, 'update_service'])->name('update.service');
		Route::post('/service/delete/{id}', [AdminToolsController::class, 'destroy_service'])->name('destroy.service');

		Route::get('/all-tags', [TagsController::class, 'index'])->name('all.tags');
		Route::get('/create-tag', [TagsController::class, 'create'])->name('add.tag');
		Route::post('/store-tag', [TagsController::class, 'store'])->name('store.tag');
		Route::get('/tag/edit/{id}', [TagsController::class, 'edit'])->name('edit.tag');
		Route::post('/tag/update/{id}', [TagsController::class, 'update'])->name('update.tag');
		Route::post('/tag/delete/{id}', [TagsController::class, 'destroy'])->name('destroy.tag');

		Route::get('/all-categories', [CategoriesController::class, 'index'])->name('all.categories');
		Route::get('/create-category', [CategoriesController::class, 'create'])->name('add.category');
		Route::post('/store-category', [CategoriesController::class, 'store'])->name('store.category');
		Route::get('/category/edit/{id}', [CategoriesController::class, 'edit'])->name('edit.category');
		Route::post('/category/update/{id}', [CategoriesController::class, 'update'])->name('update.category');
		Route::post('/category/delete/{id}', [CategoriesController::class, 'destroy'])->name('destroy.category');

		Route::get('/all-product-categories', [ProductCategoriesController::class, 'index'])->name('all.product.categories');
		Route::get('/create-product-category', [ProductCategoriesController::class, 'create'])->name('add.product.category');
		Route::post('/store-product-category', [ProductCategoriesController::class, 'store'])->name('store.product.category');
		Route::get('/product-category/edit/{id}', [ProductCategoriesController::class, 'edit'])->name('edit.product.category');
		Route::post('/product-category/update/{id}', [ProductCategoriesController::class, 'update'])->name('update.product.category');
		Route::post('/product-category/delete/{id}', [ProductCategoriesController::class, 'destroy'])->name('destroy.product.category');

		Route::get('/all-blog-posts', [PostsController::class, 'index'])->name('all.posts');
		Route::get('/create-post', [PostsController::class, 'create'])->name('add.post');
		Route::post('/store-post', [PostsController::class, 'store'])->name('store.post');
		Route::get('/post/edit/{id}', [PostsController::class, 'edit'])->name('edit.post');
		Route::post('/post/update/{id}', [PostsController::class, 'update'])->name('update.post');
		Route::post('/post/delete/{id}', [PostsController::class, 'destroy'])->name('destroy.post');

		Route::get('/all-projects', [ProjectsController::class, 'index'])->name('all.projects');
		Route::get('/create-project', [ProjectsController::class, 'create'])->name('add.project');
		Route::post('/store-project', [ProjectsController::class, 'store'])->name('store.project');
		Route::get('/project/edit/{id}', [ProjectsController::class, 'edit'])->name('edit.project');
		Route::post('/project/update/{id}', [ProjectsController::class, 'update'])->name('update.project');
		Route::post('/project/delete/{id}', [ProjectsController::class, 'destroy'])->name('destroy.project');
		
		Route::get('/all-industries', [IndustriesController::class, 'index'])->name('all.industries');
		Route::get('/create-industry', [IndustriesController::class, 'create'])->name('add.industry');
		Route::post('/store-industry', [IndustriesController::class, 'store'])->name('store.industry');
		Route::get('/industry/edit/{id}', [IndustriesController::class, 'edit'])->name('edit.industry');
		Route::post('/industry/update/{id}', [IndustriesController::class, 'update'])->name('update.industry');
		Route::post('/industry/delete/{id}', [IndustriesController::class, 'destroy'])->name('destroy.industry');

		Route::get('/app-settings', [AdminToolsController::class, 'app_settings'])->name('app.settings');
		Route::get('/slider-images', [AdminToolsController::class, 'slider_images'])->name('slider.images');
		Route::post('/update-settings', [AdminToolsController::class, 'update_settings'])->name('update.settings');
		Route::post('/change-slider-images', [AdminToolsController::class, 'change_slider_images'])->name('change.slider.images');

		Route::get('/replied-contacts', [AdminToolsController::class, 'replied_contacts'])->name('replied.contacts');
		Route::get('/unreplied-contacts', [AdminToolsController::class, 'unreplied_contacts'])->name('unreplied.contacts');
		Route::get('/view-message/{id}', [AdminToolsController::class, 'view_message'])->name('view.message');
		Route::post('/mark/replied/{id}', [AdminToolsController::class, 'mark_replied'])->name('mark.replied');
		Route::post('/mark/unreplied/{id}', [AdminToolsController::class, 'mark_unreplied'])->name('mark.unreplied');
		Route::post('/contact/delete/{id}', [AdminToolsController::class, 'destroy_contact'])->name('destroy.contact');

		Route::get('/all-products', [ProductsController::class, 'index'])->name('all.products');
		Route::get('/create-product', [ProductsController::class, 'create'])->name('add.product');
		Route::post('/store-product', [ProductsController::class, 'store'])->name('store.product');
		Route::get('/product/edit/{id}', [ProductsController::class, 'edit'])->name('edit.product');
		Route::post('/product/update/{id}', [ProductsController::class, 'update'])->name('update.product');
		Route::post('/product/delete/{id}', [ProductsController::class, 'destroy'])->name('destroy.product');

		Route::get('/all-orders', [ProductsController::class, 'all_orders'])->name('all.orders');
		Route::get('/invoice-details/{id}', [ProductsController::class, 'invoice_details'])->name('invoice.details');
	});

});
